'use strict'

const Api = require('@proak/response')

const parseResponse = (response = {}, disableStructure) =>
    response.statusCode ? response : Api.response(response, true, disableStructure)

const lambdaHandler = (actions, disableStructure = false) => async event => {
  const { httpMethod, path } = event.requestContext || {}
  console.log('event: ', JSON.stringify(event, null, 2))
  const action = typeof actions === 'function' ? actions : actions[httpMethod]
  const asyncResponse = new Promise(async (resolve, reject) => {
    try {
      const response = await action(event, (error, data) => {
        return error
            ? reject(error)
            : resolve(data)
      })
      if (response) {
        resolve(response)
      }
    } catch (error) {
      console.error(httpMethod, path, error)
      resolve(Api.error(error))
    }
  })

  return parseResponse(await asyncResponse, disableStructure)
}

module.exports = lambdaHandler
